@@ -157,7 +157,7 @@ sub _install_clean_inc {
     my $dir = shift;
     my $util_inc_path = catdir( $dir, 'inc', 'Shipwright', 'Util' );
     make_path( $util_inc_path );
-    for my $mod qw(CleanINC PatchModuleBuild) {
+    for my $mod ( qw/CleanINC PatchModuleBuild/ ) {
         rcopy( Module::Info->new_from_module("Shipwright::Util::$mod")->file,
             $util_inc_path )
           or confess_or_die "copy $mod failed: $!";
@@ -260,15 +260,22 @@ sub import {
                     $self->_add_to_order($name);
 
                     my $version = $self->version;
-                    $version->{$name}{$args{as}} = $args{version};
+                    if ( $args{as} ) {
+                        $version->{$name}{$args{as}} = $args{version};
+                    }
+                    else {
+                        $version->{$name} = $args{version};
+                    }
                     $self->version($version);
 
                     my $branches = $self->branches;
                     if ( $args{branches} ) {
 
                   # mostly this happens when import from another shipwright repo
-                        $branches->{$name} = $args{branches};
-                        $self->branches($branches);
+                        if ( @{ $args{branches} } ) {
+                            $branches->{$name} = $args{branches};
+                            $self->branches($branches);
+                        }
                     }
                     elsif (
                             $name !~ /^cpan-/ && 
