@@ -63,7 +63,7 @@ sub run {
             }
 
             $shipwright->backend->source($source);
-            $self->log->fatal( "relocated $name to $new_source with success" );
+            $self->log->fatal( "successfully relocated $name to $new_source" );
         }
     }
     else {
@@ -84,6 +84,14 @@ Shipwright::Script::Relocate - Relocate uri of a source
 
  relocate mysql http://new_uri_of_mysql.tar.gz
 
+=head1 GLOBAL OPTIONS
+
+ -r [--repository] REPOSITORY   : specify the repository uri of our shipyard
+ -l [--log-level] LOGLEVEL      : specify the log level
+                                  (info, debug, warn, error, or fatal)
+ --log-file FILENAME            : specify the log file
+
+
 =head1 AUTHORS
 
 sunnavy  C<< <sunnavy@bestpractical.com> >>
